% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary.R
\name{coef.cv.l0ara}
\alias{coef.cv.l0ara}
\title{Extract coefficients from a \code{"cv.l0ara"} object}
\usage{
\method{coef}{cv.l0ara}(object, ...)
}
\arguments{
\item{object}{Fitted "cv.l0ara" object.}

\item{...}{Not used argument.}
}
\value{
A named numeric vector of fitted coefficients.
}
\description{
Return coefficients from the model refit at the selected
  \code{lam.min}.
}
\details{
If \code{object$fit.min} is missing, the model is refit on the full
  data using \code{lam.min}.
}
\seealso{
\code{\link{predict.l0ara}}, \code{\link{l0ara}},
  \code{\link{cv.l0ara}}.
}
\author{
Wenchuan Guo <wguo1017@gmail.com>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
}
