% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary.R
\name{print.l0ara}
\alias{print.l0ara}
\title{Print a \code{"l0ara"} object}
\usage{
\method{print}{l0ara}(x, ...)
}
\arguments{
\item{x}{Fitted "l0ara" object.}

\item{...}{Not used argument.}
}
\value{
Called for its side effect of printing model information.
}
\description{
Print a short summary of a fitted model.
}
\seealso{
\code{\link{predict.l0ara}}, \code{\link{coef.l0ara}},
  \code{\link{l0ara}}.
}
\author{
Wenchuan Guo <wguo1017@gmail.com>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
}
