% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary.R
\name{coef.l0ara}
\alias{coef.l0ara}
\title{Extract coefficients from a \code{"l0ara"} object}
\usage{
\method{coef}{l0ara}(object, ...)
}
\arguments{
\item{object}{Fitted "l0ara" object.}

\item{...}{Not used argument.}
}
\value{
A named numeric vector of fitted coefficients.
}
\description{
Return the fitted coefficient vector.
}
\seealso{
\code{\link{predict.l0ara}}, \code{\link{l0ara}}.
}
\author{
Wenchuan Guo <wguo1017@gmail.com>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
}
