% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary.R
\name{plot.cv.l0ara}
\alias{plot.cv.l0ara}
\title{Plot a \code{"cv.l0ara"} object}
\usage{
\method{plot}{cv.l0ara}(x, col = 3, ...)
}
\arguments{
\item{x}{Fitted "cv.l0ara" object.}

\item{col}{Color used for the plotted points.}

\item{...}{Not used argument.}
}
\value{
Called for its side effect of producing a plot.
}
\description{
Plot the cross-validation scores against the supplied penalty
  values and mark the selected \code{lam.min}.
}
\seealso{
\code{\link{coef.cv.l0ara}}, \code{\link{cv.l0ara}},
  \code{\link{l0ara}}.
}
\author{
Wenchuan Guo <wguo1017@gmail.com>, Shujie Ma <shujie.ma@ucr.edu>, Zhenqiu Liu <Zhenqiu.Liu@cshs.org>
}
